@@ -11,7 +11,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/DARWIN/osi_file.c,v 1.12 2006/02/21 04:45:07 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/DARWIN/osi_file.c,v 1.12.2.2 2006/11/09 23:30:53 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -202,7 +202,6 @@ afs_osi_Stat(register struct osi_file *afile, register struct osi_stat *astat)
     AFS_GLOCK();
     if (code == 0) {
 	astat->size = tvattr.va_size;
-	astat->blksize = tvattr.va_blocksize;
 	astat->mtime = tvattr.va_mtime.tv_sec;
 	astat->atime = tvattr.va_atime.tv_sec;
     }
@@ -292,7 +291,7 @@ afs_osi_Read(register struct osi_file *afile, int offset, void *aptr,
 	     afs_int32 asize)
 {
     struct AFS_UCRED *oldCred;
-    unsigned int resid;
+    afs_size_t resid;
     register afs_int32 code;
 #ifdef AFS_DARWIN80_ENV
     uio_t uio;
@@ -343,7 +342,7 @@ afs_osi_Write(register struct osi_file *afile, afs_int32 offset, void *aptr,
 	      afs_int32 asize)
 {
     struct AFS_UCRED *oldCred;
-    unsigned int resid;
+    afs_size_t resid;
     register afs_int32 code;
 #ifdef AFS_DARWIN80_ENV
     uio_t uio;
