@@ -17,6 +17,7 @@
 
 #define AFS_NAMEI_ENV		1	/* User space interface to file system */
 #define AFS_64BIT_ENV		1
+#define AFS_64BIT_CLIENT	1
 #define AFS_64BIT_IOPS_ENV	1	/* Needed for NAMEI */
 #define AFS_OBSD_ENV		1
 #define AFS_OBSD34_ENV		1
@@ -42,7 +43,9 @@
 
 /* Extra kernel definitions (from kdefs file) */
 #ifdef _KERNEL
+#ifdef MULTIPROCESSOR
 #define AFS_GLOBAL_SUNLOCK	1
+#endif
 #define	AFS_SHORTGID		0	/* are group id's short? */
 
 #if	!defined(ASSEMBLER) && !defined(__LANGUAGE_ASSEMBLY__)
