@@ -36,7 +36,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/lwp/iomgr.c,v 1.13 2004/07/08 05:16:57 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/lwp/iomgr.c,v 1.16 2006/02/15 13:00:16 jaltman Exp $");
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -129,7 +129,9 @@ struct IoRequest {
     struct TM_Elem	timeout;
 
     /* Result of select call */
-    long			result;
+    int			result;
+
+    struct IoRequest    *next;	/* for iorFreeList */
 
 #ifdef AFS_DJGPP_ENV
     NCB                  *ncbp;
@@ -228,14 +230,14 @@ fd_set *IOMGR_AllocFDSet(void)
     }
 }
 
-#define FreeRequest(x) ((x)->result = (long) iorFreeList, iorFreeList = (x))
+#define FreeRequest(x) ((x)->next = iorFreeList, iorFreeList = (x))
 
 static struct IoRequest *NewRequest()
 {
     struct IoRequest *request;
 
     if ((request=iorFreeList))
-	iorFreeList = (struct IoRequest *) (request->result);
+	iorFreeList = (struct IoRequest *) (request->next);
     else request = (struct IoRequest *) malloc(sizeof(struct IoRequest));
 
     memset((char*)request, 0, sizeof(struct IoRequest));
@@ -304,7 +306,10 @@ static int FDSetCmp(int nfds, fd_set *fd_set1, fd_set *fd_set2)
  */
 static void FDSetSet(int nfds, fd_set *fd_set1, fd_set *fd_set2)
 {
-    unsigned int i, n;
+    unsigned int i;
+#ifndef AFS_NT40_ENV
+    unsigned int n;
+#endif
 
     if (fd_set1 == (fd_set*)0 || fd_set2 == (fd_set*)0)
 	return;
@@ -536,10 +541,11 @@ static int IOMGR(void *dummy)
 		iomgr_timeout.tv_sec = 100000000;
 		iomgr_timeout.tv_usec = 0;
 	    }
-#ifdef AFS_NT40_ENV
+#if defined(AFS_NT40_ENV) || defined(AFS_LINUX24_ENV)
 	    /* On NT, signals don't interrupt a select call. So this can potentially
 	     * lead to long wait times before a signal is honored. To avoid this we
 	     * dont do select() for longer than IOMGR_MAXWAITTIME (5 secs) */
+	    /* Whereas Linux seems to sometimes "lose" signals */
 	    if (iomgr_timeout.tv_sec > (IOMGR_MAXWAITTIME - 1)) {
 	      iomgr_timeout.tv_sec = IOMGR_MAXWAITTIME;
 	      iomgr_timeout.tv_usec = 0;
@@ -640,11 +646,12 @@ static int IOMGR(void *dummy)
 		/* Real timeout only if signal handler hasn't set
 		   iomgr_timeout to zero. */
 
-#ifdef AFS_NT40_ENV
+#if defined(AFS_NT40_ENV) || defined(AFS_LINUX24_ENV)
 		/* On NT, real timeout only if above and if iomgr_timeout
 		 * interval is equal to timeout interval (i.e., not adjusted
 		 * to check for pseudo-signals).
 		 */
+		/* And also for Linux as above */
 		if (iomgr_timeout.tv_sec  != timeout.tv_sec ||
 		    iomgr_timeout.tv_usec != timeout.tv_usec) {
 		    /* signal check interval timed out; not real timeout */
