@@ -11,7 +11,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/ptserver/readgroup.c,v 1.8 2003/07/15 23:16:03 shadow Exp $");
+    ("$Header: /cvs/openafs/src/ptserver/readgroup.c,v 1.10.14.1 2007/04/10 18:39:54 shadow Exp $");
 
 #include <stdio.h>
 #ifdef AFS_NT40_ENV
@@ -29,6 +29,7 @@ RCSID
 #include <rx/xdr.h>
 #include <afs/cellconfig.h>
 #include <afs/afsutil.h>
+#include <afs/com_err.h>
 #include "ptclient.h"
 #include "pterror.h"
 
@@ -36,10 +37,7 @@ int verbose = 0;
 void skip();
 
 void
-report_error(code, name, gname)
-     afs_int32 code;
-     char *name;
-     char *gname;
+report_error(afs_int32 code, char *name, char *gname)
 {
     if (code == 0) {
 	if (verbose)
@@ -65,9 +63,8 @@ osi_audit()
 
 #include "AFS_component_version_number.c"
 
-main(argc, argv)
-     afs_int32 argc;
-     char **argv;
+int
+main(int argc, char **argv)
 {
     register afs_int32 code;
     char name[PR_MAXNAMELEN];
@@ -100,6 +97,7 @@ main(argc, argv)
 	}
     }
     code = pr_Initialize(2, AFSDIR_CLIENT_ETC_DIRPATH, cellname);
+    free(cellname);
     if (code) {
 	fprintf(stderr, "pr_Initialize failed .. exiting.\n");
 	fprintf(stderr, "%s (%d).\n", pr_ErrorMsg(code), code);
@@ -217,8 +215,7 @@ main(argc, argv)
 }
 
 void
-skip(s)
-     char **s;
+skip(char **s)
 {
     while (**s != ' ' && **s != '\t' && **s != '\0')
 	(*s)++;
