@@ -22,7 +22,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/vol/partition.c,v 1.33.2.1 2007/03/20 19:00:43 shadow Exp $");
+    ("$Header: /cvs/openafs/src/vol/partition.c,v 1.33.2.2 2007/05/10 22:42:33 shadow Exp $");
 
 #include <ctype.h>
 #ifdef AFS_NT40_ENV
@@ -463,14 +463,14 @@ VAttachPartitions(void)
 	/* but allow zfs too if we're in the NAMEI environment */
 	if (
 #ifdef AFS_NAMEI_ENV
-	((!strcmp(mnt.mnt_fstype, "ufs") &&
-	  !strcmp(mnt.mnt_fstype, "zfs")))
+	    ((!(strcmp(mnt.mnt_fstype, "ufs") &&
+		strcmp(mnt.mnt_fstype, "zfs"))))
 #else
-	(strcmp(mnt.mnt_fstype, "ufs") != 0)
+	    (strcmp(mnt.mnt_fstype, "ufs") != 0)
 #endif
-	|| (strncmp(mnt.mnt_mntopts, "ro,ignore", 9) == 0))
+	    || (strncmp(mnt.mnt_mntopts, "ro,ignore", 9) == 0))
 	    continue;
-
+	
 	/* If we're going to always attach this partition, do it later. */
 	if (VIsAlwaysAttach(mnt.mnt_mountp))
 	    continue;
